@@ -6,9 +6,6 @@
     :copyright: (c) Conceptual Vision Consulting LLC 2015-2016, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
-from pip_services3_commons.config import ConfigParams
-from pip_services3_commons.run import Parameters
-from pip_services3_components.config import ConfigReader
 from pybars import Compiler
 
 
